/*
 * System Interface Library for games
 * Copyright (c) 2007-2014 Andrew Church <achurch@achurch.org>
 * Released under the GNU GPL version 3 or later; NO WARRANTY is provided.
 * See the file COPYING.txt for details.
 *
 * src/sysdep/windows/internal.h: Declarations used internally by
 * Windows-specific code.
 */

#ifndef SIL_SRC_SYSDEP_WINDOWS_INTERNAL_H
#define SIL_SRC_SYSDEP_WINDOWS_INTERNAL_H

/*************************************************************************/
/*************************************************************************/

/* System headers.  Note that we need to do a bit of magic with #defines
 * because windef.h tries to define "near" and "far" to nothing. */

#undef near
#undef far

#include <windows.h>
#include <shlobj.h>

#undef near
#undef far
#define near near_
#define far far_

/*-----------------------------------------------------------------------*/

/* Library-internal declarations. */


/******** files.c ********/

/**
 * windows_file_init:  Initialize the Windows file handling subsystem.
 *
 * [Return value]
 *     True on success, false on failure.
 */
extern int windows_file_init(void);


/******** misc.c ********/

/**
 * windows_set_error:  Record the given SYSERR_* error code as the error to
 * be returned from sys_last_error().  If code == 0, the code is instead
 * set based on the Windows error code specified by windows_code; if
 * windows_code is also zero, the current Windows error code (as returned
 * by GetLastError()) is used.
 *
 * [Parameters]
 *     code: SYSERR_* error code, or zero to use a Windows error code.
 *     windows_code: Windows error code, or zero to use the system error code.
 */
extern void windows_set_error(int code, DWORD windows_code);

/**
 * windows_strerror:  Return a text string describing the error associated
 * with the given Windows error code.  The string is stored in a static
 * buffer which will be overwritten on each call to the function.
 *
 * [Parameters]
 *     code: Windows error code.
 * [Return value]
 *     Error description (including the error code at the beginning).
 */
extern const char *windows_strerror(DWORD code);


/******** userdata.c ********/

/**
 * windows_userdata_init:  Initialize the Windows-specific userdata
 * functionality.  This must be called during program startup.
 *
 * [Return value]
 *     True on success, false on error.
 */
extern int windows_userdata_init(void);


/*************************************************************************/
/*************************************************************************/

#endif  // SIL_SRC_SYSDEP_WINDOWS_INTERNAL_H

/*
 * Local variables:
 *   c-file-style: "stroustrup"
 *   c-file-offsets: ((case-label . *) (statement-case-intro . *))
 *   indent-tabs-mode: nil
 * End:
 *
 * vim: expandtab shiftwidth=4:
 */
